@@ -20,14 +20,13 @@ from __future__ import annotations
 import warnings
 from collections.abc import Callable, Sequence
 from contextlib import suppress
-from copy import deepcopy
 from typing import (
     TYPE_CHECKING,
     Any,
 )
 
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, TaskDeferred
-from airflow.providers.common.compat.sdk import XCOM_RETURN_KEY, BaseOperator
+from airflow.exceptions import AirflowProviderDeprecationWarning
+from airflow.providers.common.compat.sdk import XCOM_RETURN_KEY, AirflowException, BaseOperator, TaskDeferred
 from airflow.providers.microsoft.azure.hooks.msgraph import KiotaRequestAdapterHook
 from airflow.providers.microsoft.azure.triggers.msgraph import (
     MSGraphTrigger,
@@ -247,7 +246,7 @@ class MSGraphAsyncOperator(BaseOperator):
     @classmethod
     def append_result(
         cls,
-        results: Any,
+        results: list[Any],
         result: Any,
         append_result_as_list_if_absent: bool = False,
     ) -> list[Any]:
@@ -312,18 +311,12 @@ class MSGraphAsyncOperator(BaseOperator):
     def paginate(
         operator: MSGraphAsyncOperator, response: dict, **context
     ) -> tuple[Any, dict[str, Any] | None]:
-        odata_count = response.get("@odata.count")
-        if odata_count and operator.query_parameters:
-            query_parameters = deepcopy(operator.query_parameters)
-            top = query_parameters.get("$top")
-
-            if top and odata_count:
-                if len(response.get("value", [])) == top and context:
-                    results = operator.pull_xcom(context)
-                    skip = sum([len(result["value"]) for result in results]) + top if results else top
-                    query_parameters["$skip"] = skip
-                    return operator.url, query_parameters
-        return response.get("@odata.nextLink"), operator.query_parameters
+        return KiotaRequestAdapterHook.default_pagination(
+            response=response,
+            url=operator.url,
+            query_parameters=operator.query_parameters,
+            responses=lambda: operator.pull_xcom(context),
+        )
 
     def trigger_next_link(self, response, method_name: str, context: Context) -> None:
         if isinstance(response, dict):
