@@ -35,36 +35,7 @@ def get_base_airflow_version_tuple() -> tuple[int, int, int]:
 AIRFLOW_V_3_0_PLUS = get_base_airflow_version_tuple() >= (3, 0, 0)
 AIRFLOW_V_3_1_PLUS = get_base_airflow_version_tuple() >= (3, 1, 0)
 
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.sdk import (
-        BaseOperator,
-        BaseOperatorLink,
-        BaseSensorOperator,
-        Connection,
-        Context,
-    )
-else:
-    from airflow.models import BaseOperator, BaseOperatorLink, Connection  # type: ignore[assignment]
-    from airflow.sensors.base import BaseSensorOperator  # type: ignore[no-redef]
-    from airflow.utils.context import Context  # type: ignore[no-redef]
-
-if AIRFLOW_V_3_1_PLUS:
-    from airflow.sdk.bases.xcom import BaseXCom
-
-    XCOM_RETURN_KEY = BaseXCom.XCOM_RETURN_KEY
-    from airflow.sdk import BaseHook
-else:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
-    from airflow.utils.xcom import XCOM_RETURN_KEY  # type: ignore[no-redef]
-
 __all__ = [
     "AIRFLOW_V_3_0_PLUS",
     "AIRFLOW_V_3_1_PLUS",
-    "BaseHook",
-    "BaseOperator",
-    "BaseOperatorLink",
-    "BaseSensorOperator",
-    "Connection",
-    "Context",
-    "XCOM_RETURN_KEY",
 ]
